@@ -170,23 +170,21 @@ class PythonConsole(Gtk.ScrolledWindow): # pylint: disable=R0902
             GLib.idle_add(self.scroll_to_end)
             return True
 
-        elif event.keyval == Gdk.KEY_KP_Down or event.keyval == Gdk.KEY_Down:
+        elif event.keyval in (Gdk.KEY_KP_Down, Gdk.KEY_Down):
             # Next entry from history
             view.emit_stop_by_name("key_press_event")
             self.history_down()
             GLib.idle_add(self.scroll_to_end)
             return True
 
-        elif event.keyval == Gdk.KEY_KP_Up or event.keyval == Gdk.KEY_Up:
+        elif event.keyval in (Gdk.KEY_KP_Up, Gdk.KEY_Up):
             # Previous entry from history
             view.emit_stop_by_name("key_press_event")
             self.history_up()
             GLib.idle_add(self.scroll_to_end)
             return True
 
-        elif event.keyval == Gdk.KEY_KP_Left or \
-             event.keyval == Gdk.KEY_Left or \
-             event.keyval == Gdk.KEY_BackSpace:
+        elif event.keyval in (Gdk.KEY_KP_Left, Gdk.KEY_Left, Gdk.KEY_BackSpace):
             buf = view.get_buffer()
             inp = buf.get_iter_at_mark(buf.get_mark("input"))
             cur = buf.get_iter_at_mark(buf.get_insert())
@@ -293,8 +291,7 @@ class PythonConsole(Gtk.ScrolledWindow): # pylint: disable=R0902
             except SyntaxError:
                 exec(command, self.namespace) # pylint: disable=W0122
         except: # pylint: disable=W0702
-            if hasattr(sys, 'last_type') and \
-               sys.last_type == SystemExit: # pylint: disable=E1101
+            if hasattr(sys, 'last_type') and sys.last_type == SystemExit: # pylint: disable=E1101
                 self.destroy()
             else:
                 traceback.print_exc()
@@ -319,20 +316,20 @@ class OutFile:
         pass
     def fileno(self):
         return self.file_no
-    def isatty(self): # pylint: disable=R0201
+    def isatty(self):
         return 0
-    def read(self, _): # pylint: disable=R0201
+    def read(self, _):
         return ''
-    def readline(self): # pylint: disable=R0201
+    def readline(self):
         return ''
-    def readlines(self): # pylint: disable=R0201
+    def readlines(self):
         return []
     def write(self, seg):
         self.console.write(seg, self.tag)
     def writelines(self, lines):
         self.console.write(lines, self.tag)
-    def seek(self, _): # pylint: disable=R0201
+    def seek(self, _):
         raise IOError((29, 'Illegal seek'))
-    def tell(self): # pylint: disable=R0201
+    def tell(self):
         raise IOError((29, 'Illegal seek'))
     truncate = tell
