@@ -97,12 +97,6 @@ totem_data_dot_dir (void)
 	return (const char *)totem_dir;
 }
 
-char *
-totem_pictures_dir (void)
-{
-	return g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_PICTURES));
-}
-
 static GMount *
 totem_get_mount_for_uri (const char *path)
 {
